
import React from 'react';
import { Button } from '@/components/ui/button';
import { useTheme } from '../contexts/ThemeContext';
import { FiMenu, FiMessageSquare, FiExternalLink, FiHelpCircle, FiUsers, FiDollarSign, FiZap } from 'react-icons/fi';

interface LeftSidebarProps {
  onPromptSelect: (prompt: string, content: any) => void;
}

const suggestedQuestions = [
  { text: "What is MCP?", icon: FiHelpCircle },
  { text: "Who is this for?", icon: FiUsers },
  { text: "Show me how I can earn", icon: FiDollarSign },
  { text: "What can you help me with?", icon: FiZap },
];

const LeftSidebar: React.FC<LeftSidebarProps> = ({ onPromptSelect }) => {
  const { sidebarOpen, setSidebarOpen } = useTheme();

  const handlePromptClick = (prompt: string) => {
    // This will trigger the same logic as in ChatInterface
    onPromptSelect(prompt, null);
  };

  return (
    <>
      {/* Toggle Button */}
      {!sidebarOpen && (
        <Button
          variant="ghost"
          onClick={() => setSidebarOpen(true)}
          className="fixed top-24 left-4 z-50 w-10 h-10 rounded-full border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-sm bg-white/10 dark:bg-black/10 hover:bg-white/20 dark:hover:bg-black/20 transition-all duration-300"
        >
          <FiMenu className="w-4 h-4" />
        </Button>
      )}

      {/* Sidebar */}
      <div
        className={`fixed left-0 top-20 h-[calc(100vh-80px)] w-64 transform transition-transform duration-500 ease-in-out z-40 ${
          sidebarOpen ? 'translate-x-0' : '-translate-x-full'
        }`}
      >
        <div className="h-full border-r border-gray-200/20 dark:border-gray-700/20 backdrop-blur-xl bg-white/95 dark:bg-black/95">
          <div className="p-6 h-full">
            <div className="flex items-center justify-between mb-6">
              <h2 className="text-lg font-semibold text-gray-900 dark:text-white">
                Quick Actions
              </h2>
              <Button
                variant="ghost"
                onClick={() => setSidebarOpen(false)}
                className="w-8 h-8 rounded-full hover:bg-gray-100 dark:hover:bg-gray-800"
              >
                <svg className="w-4 h-4" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                </svg>
              </Button>
            </div>

            {/* Suggested Questions */}
            <div className="space-y-4 mb-8">
              <h3 className="text-sm font-medium text-gray-600 dark:text-gray-400 uppercase tracking-wide">
                Suggested Questions
              </h3>
              <div className="space-y-2">
                {suggestedQuestions.map((question, index) => (
                  <Button
                    key={index}
                    variant="ghost"
                    onClick={() => handlePromptClick(question.text)}
                    className="w-full justify-start p-3 h-auto text-left border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-sm bg-white/5 dark:bg-black/5 hover:bg-white/10 dark:hover:bg-black/10 rounded-xl transition-all duration-300"
                  >
                    <question.icon className="w-4 h-4 mr-3 text-gray-500 dark:text-gray-400" />
                    <span className="text-sm text-gray-700 dark:text-gray-300">{question.text}</span>
                  </Button>
                ))}
              </div>
            </div>

            {/* Website Link */}
            <div className="space-y-4">
              <h3 className="text-sm font-medium text-gray-600 dark:text-gray-400 uppercase tracking-wide">
                Resources
              </h3>
              <Button
                variant="ghost"
                asChild
                className="w-full justify-start p-3 h-auto text-left border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-sm bg-white/5 dark:bg-black/5 hover:bg-white/10 dark:hover:bg-black/10 rounded-xl transition-all duration-300"
              >
                <a href="https://yourdomain.com" target="_blank" rel="noopener noreferrer">
                  <FiExternalLink className="w-4 h-4 mr-3 text-gray-500 dark:text-gray-400" />
                  <span className="text-sm text-gray-700 dark:text-gray-300">Visit Our Website</span>
                </a>
              </Button>
            </div>
          </div>
        </div>
      </div>
    </>
  );
};

export default LeftSidebar;
